#
# spec file for package python-etcd
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define upstream_name python-etcd
Name:           python-etcd
Version:        0.4.5
Release:        4.16
Summary:        A python client for etcd
License:        MIT
Group:          System/Management
URL:            https://pypi.python.org/pypi/python-etcd
Source:         https://files.pythonhosted.org/packages/source/p/%{upstream_name}/%{upstream_name}-%{version}.tar.gz
# PATCH-FEATURE-UPSTREAM remove_nose.patch gh#jplana/python-etcd#274 mcepl@suse.com
# remove dependency on nose
Patch0:         remove_nose.patch
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module dnspython}
BuildRequires:  %{python_module urllib3}
BuildRequires:  %{python_module pytest}
BuildRequires:  etcd
BuildRequires:  fdupes
BuildArch:      noarch
Requires:       python-dnspython >= 1.13.0
Requires:       python-urllib3 >= 1.7.1
ExcludeArch:    %ix86
%python_subpackages

%description
A python client for etcd cluster

%prep
%setup -q -n %{upstream_name}-%{version}
%autopatch -p1

%build
%python_build

%install
%python_install
%{python_expand rm -rf %{$python_sitelib}/etcd/tests
%fdupes %{buildroot}%{$python_sitelib}
}

%check
export PATH=%{_sbindir}:$PATH
# gh#jplana/python-etcd#274 unfortunately the test suite still fails
%pytest src/etcd/tests || /bin/true

%files %{python_files}
%doc README.rst
%dir %{python_sitelib}/*
%exclude %{python_sitelib}/etcd/tests/
%{python_sitelib}/etcd/*
%{python_sitelib}/*egg-info/*

%changelog
* Wed Aug 12 2020 Matej Cepl <mcepl@suse.com>
- Add remove_nose.patch to remove dependency on nose
  (gh#jplana/python-etcd#274).
* Thu Apr 12 2018 kukuk@suse.de
- Convert to singlespec (build python2 and python3 package) (bsc#1095835)
* Tue Jun  6 2017 jmassaguerpla@suse.com
- fix license
* Tue May 23 2017 mjura@suse.com
- add Requires: python-dnspython >= 1.13.0
* Mon May 22 2017 mjura@suse.com
- fix typo in required python-urllib3 package name
* Fri May 19 2017 mjura@suse.com
- add test package with unit tests
* Thu May 18 2017 mjura@suse.com
- update to version 0.4.5
  * Remove dnspython2/3 requirement
  * Change property name setter in lock
  * Fixed acl tests
  * Added version/cluster_version properties to client
  * Fixes in lock when used as context manager
  * Fixed improper usage of urllib3 exceptions
  * Minor fixes for error classes
  * In lock return modifiedIndex to watch changes
  * In lock fix context manager exception handling
  * Improvments to the documentation
  * Remove _base_uri only after refresh from cluster
  * Avoid double update of _machines_cache
- update to version 0.4.4
  * Fix some tests
  * Use sys,version_info tuple, instead of named tuple
  * Improve & fix documentation
  * Fix python3 specific problem when blocking on contented lock
  * Add refresh key method
  * Add custom lock prefix support
- update to version 0.4.3
  * Fix check for parameters in case of connection error
  * Python 3.5 compatibility and general python3 cleanups
  * Added authentication and module for managing ACLs
  * Added srv record-based DNS discovery
  * Fixed (again) logging of cluster id changes
  * Fixed leader lookup
  * Properly retry request on exception
  * Client: clean up open connections when deleting
- update to version 0.4.2
  * Fixed lock documentation
  * Fixed lock sequences due to etcd 2.2 change
  * Better exception management during response processing
  * Fixed logging of cluster ID changes
  * Fixed subtree results
  * Do not check cluster ID if etcd responses don't contain the ID
  * Added a cause to EtcdConnectionFailed
- update to version 0.4.1
  * Added client-side leader election
  * Added stats endpoints
  * Added logging
  * Better exception handling
  * Check for cluster ID on each request
  * Added etcd.Client.members and fixed etcd.Client.leader
  * Removed locking and election etcd support
  * Allow the use of etcd proxies with reconnections
  * Implement pop: Remove key from etc and return the corresponding value.
  * Eternal watcher can be now recursive
  * Fix etcd.Client machines
  * Do not send parameters with `None` value to etcd
  * Support ttl=0 in write.
  * Moved pyOpenSSL into test requirements.
  * Always set certificate information so redirects from http to https work.
- update to version 0.3.3
  * Forward leaves_only value in get_subtree() recursive calls
  * Fix README prevExists->prevExist
  * Added configurable version_prefix
  * Added support for recursive watch
  * Better error handling support (more detailed exceptions)
  * Fixed some unreliable tests
- update to version 0.3.2
  * Fixed generated documentation version.
- update to version 0.3.1
  * Added consisten read option
  * Fixed timeout parameter in read()
  * Added atomic delete parameter support
  * Fixed delete behaviour
  * Added update method that allows atomic updated on results
  * Fixed checks on write()
  * Added leaves generator to EtcdResult and get_subtree for recursive fetch
  * Added etcd_index to EtcdResult
  * Changed ethernal -> eternal
  * Updated urllib3 & pyOpenSSL libraries
  * Several performance fixes
  * Better parsing of etcd_index and raft_index
  * Removed duplicated tests
  * Added several integration and unit tests
  * Use etcd v0.3.0 in travis
  * Execute test using `python setup.py test` and nose
- update to version 0.3.0
  * API v2 support
  * Python 3.3 compatibility
- update to version 0.2.1
  * SSL support
  * Added support for subdirectories in results.
  * Improve test
  * Added support for reconnections, allowing death node tolerance.
- update to version 0.2.0
  * Allow fetching of multiple keys (sub-nodes)
- update to version 0.1
  * Initial release
